This function allows to plot any qualit-control figures available
within the shiny app using visualise() or in the HTML report from render().
# S3 method for nacho
autoplot(
object,
x,
colour = "CartridgeID",
size = 0.5,
show_legend = TRUE,
show_outliers = TRUE,
outliers_factor = 1,
outliers_labels = NULL,
...
)[list] List obtained from load_rcc() or normalise().
[character] Character string naming the quality-control metrics to plot from nacho_object.
The possible values are:
"BD" (Binding Density)
"FoV" (Imaging)
"PCL" (Positive Control Linearity)
"LoD" (Limit of Detection)
"Positive" (Positive Controls)
"Negative" (Negative Controls)
"Housekeeping" (Housekeeping Genes)
"PN" (Positive Controls vs. Negative Controls)
"ACBD" (Average Counts vs. Binding Density)
"ACMC" (Average Counts vs. Median Counts)
"PCA12" (Principal Component 1 vs. 2)
"PCAi" (Principal Component scree plot)
"PCA" (Principal Components planes)
"PFNF" (Positive Factor vs. Negative Factor)
"HF" (Housekeeping Factor)
"NORM" (Normalisation Factor)
[character] Character string of the column in ssheet_csv
or more generally in nacho_object$nacho to be used as grouping colour.
[numeric] A numeric controlling point size
(ggplot2::geom_point()
or line size (ggplot2::geom_line()).
[logical] Boolean to indicate whether the plot legends should
be plotted (TRUE) or not (FALSE). Default is TRUE.
[logical] Boolean to indicate whether the outliers should be highlighted
in red (TRUE) or not (FALSE). Default is TRUE.
[numeric] Size factor for outliers compared to size. Default is 1.
[character] Character to indicate which column in nacho_object$nacho
should be used to be printed as the labels for outliers or not. Default is NULL.
Other arguments (Not used).
data(GSE74821)
autoplot(GSE74821, x = "BD")
Run the code above in your browser using DataLab