Learn R Programming

NACHO (version 2.0.6)

deploy: Deploy (copy) the shiny application to the specified directory

Description

Deploy (copy) the shiny application to the specified directory

Usage

deploy(directory = "/srv/shiny-server", app_name = "NACHO")

Value

[logical] A logical indicating whether the deployment is successfull (TRUE) or not (FALSE).

Arguments

directory

[character] A character vector of one path to the new location.

app_name

[character] A character vector defining the shiny application name in the new location.

Examples

Run this code

deploy(directory = ".")

if (interactive()) {
  shiny::runApp("NACHO")
}

Run the code above in your browser using DataLab