powered by
Deploy (copy) the shiny application to the specified directory
deploy(directory = "/srv/shiny-server", app_name = "NACHO")
[logical] A logical indicating whether the deployment is successfull (TRUE) or not (FALSE).
TRUE
FALSE
[character] A character vector of one path to the new location.
[character] A character vector defining the shiny application name in the new location.
deploy(directory = ".") if (interactive()) { shiny::runApp("NACHO") }
Run the code above in your browser using DataLab