This function allows to print text and figures from the results of a call to load_rcc()
or normalise().
It is intended to be used in a Rmarkdown chunk.
# S3 method for nacho
print(
x,
colour = "CartridgeID",
size = 0.5,
show_legend = FALSE,
show_outliers = TRUE,
outliers_factor = 1,
outliers_labels = NULL,
echo = FALSE,
title_level = 1,
xaringan = FALSE,
...
)[list] A list object of class "nacho" obtained from load_rcc() or normalise().
[character] Character string of the column in ssheet_csv
or more generally in nacho_object$nacho to be used as grouping colour.
[numeric] A numeric controlling point size
(ggplot2::geom_point()
or line size (ggplot2::geom_line()).
[logical] Boolean to indicate whether the plot legends should
be plotted (TRUE) or not (FALSE). Default is TRUE.
[logical] Boolean to indicate whether the outliers should be highlighted
in red (TRUE) or not (FALSE). Default is TRUE.
[numeric] Size factor for outliers compared to size. Default is 1.
[character] Character to indicate which column in nacho_object$nacho
should be used to be printed as the labels for outliers or not. Default is NULL.
[logical] A boolean to indicate whether text and plots should be printed. Mainly for use within a Rmarkdown chunk.
[numeric] A numeric to indicate the title level to start with, using markdown style,
i.e., the number of "#".
[logical] A boolean to format output for Xaringan slides.
Other arguments (Not used).
data(GSE74821)
print(GSE74821)
Run the code above in your browser using DataLab